import tomllib
from pathlib import Path

from doimbu.paths import PYPROJECT_TOML_PATH


def get_version(pyproject_toml_path: Path) -> str:
    with pyproject_toml_path.open(mode='rb') as f:
        return tomllib.load(f)["tool"]["poetry"]["version"]


__version__ = get_version(PYPROJECT_TOML_PATH)



from doimbu import get_version

from tests.paths import TEST_PYPROJECT_TOML_PATH


def test_get_version() -> None:
    version = get_version(TEST_PYPROJECT_TOML_PATH)

    assert len(version.split('.')) == 3

    assert all((version_section.isdigit()
                for version_section in version.split('.')))
